@@ -4,18 +4,14 @@ from uuid import UUID
 
 import rest_framework
 from rest_framework import fields, relations
-from rest_framework.exceptions import ValidationError
 
 from .action import Actions
-from .mixins import (
-    ActionMixin, RenderMixin, DisplayMode, NullChoiceMixin, RelatedFieldAJAXMixin, FieldHelpTextMixin,
-    DateTimeFieldMixin, DateFieldMixin, TimeFieldMixin, HiddenFieldMixin
-)
+from .mixins import (ActionMixin, AllowTagsMixin, DateFieldMixin, DateTimeFieldMixin, DisplayMode, FieldHelpTextMixin,
+                     HiddenFieldMixin, NullChoiceMixin, RelatedFieldAJAXMixin, RenderMixin, TimeFieldMixin)
 from .settings import version_check
 
 
 class BooleanField(RenderMixin, ActionMixin, FieldHelpTextMixin, fields.BooleanField):
-    NULL_VALUES = {'null', 'Null', 'NULL', '', None}
 
     def __init__(self, read_only=False, write_only=False, required=None, default=fields.empty, initial=fields.empty,
                  source=None, label=None, help_text=None, style=None, error_messages=None, validators=None,
@@ -25,23 +21,6 @@ class BooleanField(RenderMixin, ActionMixin, FieldHelpTextMixin, fields.BooleanF
         kwargs.update(kw)
         super().__init__(**kwargs)
 
-    def to_internal_value(self, data):
-        try:
-            parent_value = super().to_internal_value(data)
-            return parent_value
-        except TypeError:  # Input is an unhashable type
-            pass
-        except ValidationError:
-            if data in self.NULL_VALUES and self.allow_null:
-                return None
-        self.fail('invalid', input=data)
-
-    def to_representation(self, value):
-        parent_value = super().to_representation(value)
-        if value in self.NULL_VALUES and self.allow_null:
-            return None
-        return parent_value
-
 
 class NullBooleanField(RenderMixin, ActionMixin, FieldHelpTextMixin, fields.NullBooleanField):
 
@@ -230,11 +209,11 @@ class DurationField(RenderMixin, ActionMixin, FieldHelpTextMixin, fields.Duratio
         super().__init__(**kwargs)
 
 
-class ChoiceField(NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin, fields.ChoiceField):
+class ChoiceField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin, fields.ChoiceField):
 
     def __init__(self, choices, read_only=False, write_only=False, required=None, default=fields.empty,
                  initial=fields.empty, source=None, label=None, help_text=None, style=None, error_messages=None,
-                 validators=None, allow_null=False, actions: Actions = None, uuid: UUID = None,
+                 validators=None, allow_null=False, allow_tags=False, actions: Actions = None, uuid: UUID = None,
                  display: DisplayMode = None, display_table: DisplayMode = None, display_form: DisplayMode = None,
                  table_classes: str = '', **kw):
         kwargs = {k: v for k, v in locals().items() if not k.startswith(('__', 'self', 'kw'))}
@@ -242,11 +221,11 @@ class ChoiceField(NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
         super().__init__(**kwargs)
 
 
-class MultipleChoiceField(NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin, fields.MultipleChoiceField):
-
+class MultipleChoiceField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
+                          fields.MultipleChoiceField):
     def __init__(self, choices, read_only=False, write_only=False, required=None, default=fields.empty,
                  initial=fields.empty, source=None, label=None, help_text=None, style=None, error_messages=None,
-                 validators=None, allow_null=False, actions: Actions = None, uuid: UUID = None,
+                 validators=None, allow_null=False, allow_tags=False, actions: Actions = None, uuid: UUID = None,
                  display: DisplayMode = None, display_table: DisplayMode = None, display_form: DisplayMode = None,
                  table_classes: str = '', **kw):
         kwargs = {k: v for k, v in locals().items() if not k.startswith(('__', 'self', 'kw'))}
@@ -254,12 +233,12 @@ class MultipleChoiceField(NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTe
         super().__init__(**kwargs)
 
 
-class FilePathField(NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin, fields.FilePathField):
-
+class FilePathField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
+                    fields.FilePathField):
     def __init__(self, path, match=None, recursive=False, allow_files=True, allow_folders=False, required=None,
                  read_only=False, write_only=False, default=fields.empty, initial=fields.empty, source=None,
                  label=None, help_text=None, style=None, error_messages=None, validators=None, allow_null=False,
-                 actions: Actions = None, uuid: UUID = None, display: DisplayMode = None,
+                 allow_tags=False, actions: Actions = None, uuid: UUID = None, display: DisplayMode = None,
                  display_table: DisplayMode = None, display_form: DisplayMode = None, table_classes: str = '', **kw):
         kwargs = {k: v for k, v in locals().items() if not k.startswith(('__', 'self', 'kw'))}
         kwargs.update(kw)
@@ -454,7 +433,7 @@ class SlugRelatedField(RelatedFieldAJAXMixin, RenderMixin, ActionMixin, FieldHel
         super().__init__(**kwargs)
 
 
-class ManyRelatedField(RenderMixin, ActionMixin, FieldHelpTextMixin, relations.ManyRelatedField):
+class ManyRelatedField(RelatedFieldAJAXMixin, RenderMixin, ActionMixin, FieldHelpTextMixin, relations.ManyRelatedField):
 
     def __init__(self, child_relation=None, read_only=False, write_only=False, required=None, default=fields.empty,
                  initial=fields.empty, source=None, label=None, help_text=None, style=None, error_messages=None,
